<template>
  <div class="app-container">
    <el-form
      :model="queryParams"
      ref="tableList"
      :inline="true"
      label-width="76px"
      style="margin: 10px 10px"
    >
      <el-form-item label="体检时间" prop="date">
        <el-date-picker
          v-model="value1"
          type="datetimerange"
          align="right"
          start-placeholder="开始日期"
          end-placeholder="结束日期"
          :default-time="['00:00:00', '23:00:00']"
          format="yyyy-MM-dd HH:mm"
          value-format="yyyy-MM-dd HH:mm"
          :picker-options="pickerOptions"
          @change="dateChangebirthday1"
        >
        </el-date-picker>
      </el-form-item>
      <el-form-item>
        <el-button type="primary" icon="el-icon-search" @click="submitForm">搜索</el-button>
        <el-button type="primary"  >
          <download-excel class="blueBtn" 
            :data="resultList" 
            :fields="json_fields" 
            worksheet="My Worksheet"
            name="体检结果异常数据统计分析"
            >
            导出excel
          </download-excel>
        </el-button>
          
        
      </el-form-item>
    </el-form>

    <div class="tj">
        <span class="tj_txt">体检结果异常数据统计分析</span>
    </div>

    <div >
      <el-table :data="resultList" style="width: 96%;margin: 10px 15px;" height="530px">
    <el-table-column  prop="nweID"  label="序号"  align="center" ></el-table-column>
    <el-table-column prop="abProName" label="异常项目"  align="center"></el-table-column>
    <el-table-column prop="tjPersonNum" label="体检人数"  align="center"></el-table-column>
    <el-table-column prop="abPersonNum" label="结果异常人数"  align="center"></el-table-column>
    <el-table-column label="性别分类（异常人数）" align="center" >
        <el-table-column prop="abManNum" label="男"  align="center"></el-table-column>
        <el-table-column prop="abWomanNum" label="女"  align="center"></el-table-column>
    </el-table-column>
    <el-table-column label="年龄分类（异常人数）" align="center" >
            <el-table-column prop="abThNum" label="<30岁"  align="center"></el-table-column>
            <el-table-column prop="abThSeNum" label="30-70岁"  align="center"></el-table-column>
            <el-table-column prop="abSeNum" label=">70岁"  align="center"></el-table-column>
        </el-table-column>
  </el-table>
    </div>
   
    
  </div>
</template>

<script>
import { getResult } from "@/api/count/examination";

export default {
  name: "examination",
  data() {
    return {
        // 遮罩层
      loading: true,
        resultList:[],
        value1: "",
        startTime: "",
        queryParams: {
            date: null,
            startDate: null,
            endDate: null,
        },
        pickerOptions: {
          shortcuts: [{
            text: '最近一周',
            onClick(picker) {
              const end = new Date();
              const start = new Date();
              start.setTime(start.getTime() - 3600 * 1000 * 24 * 7);
              picker.$emit('pick', [start, end]);
            }
          }, {
            text: '最近一个月',
            onClick(picker) {
              const end = new Date();
              const start = new Date();
              start.setTime(start.getTime() - 3600 * 1000 * 24 * 30);
              picker.$emit('pick', [start, end]);
            }
          }, {
            text: '最近三个月',
            onClick(picker) {
              const end = new Date();
              const start = new Date();
              start.setTime(start.getTime() - 3600 * 1000 * 24 * 90);
              picker.$emit('pick', [start, end]);
            }
          }]
        },
        json_fields:{
          '序号':'nweID',
          '异常项目':'abProName',
          '体检人数':'tjPersonNum',
          '结果异常人数':'abPersonNum',
          '男性异常人数':'abManNum',
          '女性异常人数':'abWomanNum',
          '30岁以下异常人数':'abThNum',
          '30-70岁以下异常人数':'abThSeNum',
          '70岁以上异常人数':'abSeNum',
        },
        // 查询参数
        queryParams:{
            abProName:null,
            tjPersonNum:null,
            abPersonNum:null,
            abManNum:null,
            abWomanNum:null,
            abThNum:null,
            abThSeNum:null,
            abSeNum:null,
        },
        // 表单参数
      form: {},

    };
  },
   created() {
    this.getList();
  },
  methods: {
    // 查询体检结果异常数据列表
     getList() {
         this.loading = true;
      this.queryParams.startDate = this.startTime[0];
      this.queryParams.endDate = this.startTime[1];
      getResult(this.queryParams).then(response => {
        this.resultList = response;
         for (let i = 0; i < response.length; i++) {
          response[i].nweID = i + 1;
        }
        this.loading = false
      });
    },
    // 时间
    dateChangebirthday1(val) {
      this.startTime = val;
    },
    // 搜索
    submitForm() {
      // this.queryParams.pageNum = 1;
      this.getList();
    },
  },
};
</script>

<style lang="scss" scoped>
.tj_txt{
    display: flex;
    justify-content: center;
    margin-bottom: 30px;
}
</style>